SequentialModuleItem

Trait SequentialModuleItem 

pub trait SequentialModuleItem: UnaryModule + Debug { }
Marker trait for items that can be used in a Sequential module.

It is implemented for all types that implement Module and std::fmt::Debug.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors